@@ -227,11 +227,9 @@ def time_extract(text):
     keyDate = {'今天': 0, '明天': 1, '后天': 2, '昨天': -1, '前天': -2}
     timedic = ['时', '分', '到']
     tmptext = []
-    path = './rule_date/dict.txt'
-    if not path:
-        path = pkg_resources.resource_filename(
-            __name__, "./rule_date/dict.txt"
-        )
+    path = pkg_resources.resource_filename(    # 包的路径
+        __name__, "dict.txt"
+    )
     jieba.load_userdict(path)  # 自定义分词词典
     for k, v in psg.cut(text):  # k: 词语, v: 词性
         tmptext.append([k, v])
@@ -303,6 +301,7 @@ if __name__ == '__main__':
           '明天中午12点', '后天中午12点', "这周三中午12点",
           '昨天下午3点', '昨天上午11点', '昨天中午12点',
           ]
-    l = ["今晚5点"]
+    l = ["今晚5点", "星期三", "这周三", "这周六", "这周日", "周末", "星期日",
+         "明天中午11点", '明天中午12点', '明天中午1点', "明天上午11点"]
     for text in l:
         print(text, time_extract(text), sep=': ')
